@@ -10,21 +10,21 @@
 # Eigene Dateien/Martin/SOAP-WSDL/trunk/bin/FortuneCookie.xml"
 
 use lib 'lib/';
-use MyInterfaces::FullerData_x0020_Fortune_x0020_Cookie;
-my $cookieService = MyInterfaces::FullerData_x0020_Fortune_x0020_Cookie->new();
+use MyInterfaces::FullerData_x0020_Fortune_x0020_Cookie::FullerData_x0020_Fortune_x0020_CookieSoap;
+my $cookieService = MyInterfaces::FullerData_x0020_Fortune_x0020_Cookie::FullerData_x0020_Fortune_x0020_CookieSoap->new();
 
 my $cookie;
 $cookie = $cookieService->GetFortuneCookie()
   or die "$cookie";
 
-print $cookie; # ->get_GetFortuneCookieResult()->get_value, "\n";
+print $cookie->get_GetFortuneCookieResult()->get_value, "\n\n";
 
 $cookie = $cookieService->GetSpecificCookie({ index => 23 })
   or die "$cookie";
 
 print $cookie->get_GetSpecificCookieResult(), "\n";
 
-print $cookie;
+# print $cookie;
 
 
 =for demo:
