@@ -1,7 +1,7 @@
 package SOAP::WSDL::XSD::Typelib::Builtin::IDREFS;
 use strict;
 use warnings;
-use Class::Std::Fast::Storable;
+use Class::Std::Fast::Storable constructor => 'none', cache => 1;
 use base qw(
     SOAP::WSDL::XSD::Typelib::Builtin::list
     SOAP::WSDL::XSD::Typelib::Builtin::IDREF);
